Changelog
=========


0.10 (2018-01-20)
-----------------

- replace --idle-list with a more permissive --ignore-list https://github.com/jpcw/checkopenbgpd/issues/5
- fix broken Python3 https://github.com/jpcw/checkopenbgpd/issues/4


0.9 (2017-03-07)
----------------

- fix session with max-prefix https://github.com/jpcw/checkopenbgpd/issues/3
  
  thanks drustan for bug report
  
  thanks Dam64 which up a session with max-prefix for tests and debug


0.8 (2016-04-15)
----------------

- python3.5 support


0.7 (2015-04-12)
----------------

- fix 'idle' breaks performance data rendering https://github.com/jpcw/checkopenbgpd/issues/1


0.6 (2015-04-09)
----------------

- improve summary

0.5
----------------

- Fix Cosmetics on README

0.1 (2015-04-09)
----------------

- Jean-Philippe Camguilhem <jpcw__at__camguilhem.net>
